<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <title>{% block title %}{% endblock title %}</title>
    <link href="{{ STATIC_URL }}websettings/css/bootstrap.min.css" rel="stylesheet" media="screen">
    <style type="text/css">
        body {
            padding-top: 60px;
        }
    </style>
    <!--[if lt IE 9]>
      <script src="//html5shim.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->
    {% block extra_head %}{% endblock extra_head %}
</head>

<body>
<div class="navbar navbar-fixed-top">
    <div class="navbar-inner">
        <div class="container">
            <a class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
            </a>
            <a class="brand" href="{% url 'websettings.views.list_view' %}">WebSettings</a>
            <div class="nav-collapse">
                <ul class="nav">
                </ul>
            </div><!--/.nav-collapse -->
        </div>
    </div>
</div>

<div class="container">

    {% block content %}{% endblock content %}

</div> <!-- container -->
</body>
</html>
